@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,6 @@
 #include "system_defines.h"
 #include "apply_server_settings.h"
 #include "allocate.h"
-#include "commented.h"
 #include "commands.h"
 #include "populate_server_settings.h"
 #include "populate_conf_tab.h"
@@ -46,7 +45,7 @@ int has_value(gchar *input)
     int have_value = 0;
 
     if( input!=NULL && strlen(input) > 2 )
-      have_value = 1;
+        have_value = 1;
 
     return have_value;
 }
@@ -63,8 +62,8 @@ void add_firestarter_user_pre()
 
     if((fp=fopen(FIRESTARTER_USER_PRE, "r"))==NULL)
     {
-	/* Dont show a popup */
-	return;
+        /* Dont show a popup */
+        return;
     }
     fseek(fp, 0, SEEK_END);
     file_size = ftell(fp);
@@ -79,28 +78,28 @@ void add_firestarter_user_pre()
             continue;
 
         if( cmplowercase(line, "-a input -i tap+ -j accept") )
-          have_tap_lines++;
+            have_tap_lines++;
 
         if( cmplowercase(line, "-a output -o tap+ -j accept") )
-          have_tap_lines++;
+            have_tap_lines++;
 
         if( cmplowercase(line, "-a forward -i tap+ -j accept") )
-          have_tap_lines++;
+            have_tap_lines++;
     }
     fclose(fp);
     free(line);
 
     /* Dont add the tap+ lines if they already exist */
     if( have_tap_lines >= 3 )
-      return;
+        return;
 
-    /* Append the lines. Does Firestarter allow broadcast traffic ? Fix if it doesnt  */
+    /* Append the lines. */
     conf = g_strdup_printf("$IPT -A INPUT -i tap+ -j ACCEPT\n$IPT -A OUTPUT -o tap+ -j ACCEPT\n$IPT -A FORWARD -i tap+ -j ACCEPT\n");
     if((fp=fopen(FIRESTARTER_USER_PRE, "a"))==NULL)
     {
-	/* Show a popup */
-	g_free(conf);
-	return;
+        /* Show a popup */
+        g_free(conf);
+        return;
     }
     fputs(conf, fp);
     fclose(fp);
@@ -147,9 +146,6 @@ void apply_server_settings(struct w *widgets)
     gchar *redirect_gateway=NULL, *compression=NULL;
     gchar *share_internet=NULL, *client_auth_line=NULL;
 
-
-    /* Certificate settings are saved when generating certificates */
-
     /* Entries */
     external_iface_name    = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[0]));
     external_iface_address = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[1]));
@@ -161,6 +157,7 @@ void apply_server_settings(struct w *widgets)
     server_user            = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[7]));
     server_group           = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[8]));
     client_dns             = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[9]));
+    /* Certificate and key entries are filled in when generating keys */
 
     /* Spin buttons */
     server_port   = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_spinbutton[0]));
@@ -173,50 +170,51 @@ void apply_server_settings(struct w *widgets)
     /* Add the server group if it doesnt exist */
     if( ! group_exists(server_group) )
     {
-	cmd = g_strdup_printf("%s '%s'", ADDGROUP, server_group);
-	if( ! run_command(cmd) )
-	{
-	    info = g_strdup_printf(_("Error adding group: %s\n"), server_group);
-	    show_info(info);
-	    g_free(info);
-	    return;
-	}
-	g_free(cmd);
+        cmd = g_strdup_printf("%s '%s'", ADDGROUP, server_group);
+        if( ! run_command(cmd) )
+        {
+            info = g_strdup_printf(_("Error adding group: %s\n"), server_group);
+            show_info(info);
+            g_free(info);
+            return;
+        }
+        g_free(cmd);
     }
     /* Add the server user to the server group if it doesnt exist */
     if( ! user_exists(server_user) )
     {
-	cmd = g_strdup_printf("%s '%s' -g '%s' -d /dev/null -c '%s' -s /dev/null", ADDUSER, server_user, server_group, "GAdmin-OpenVPN-Server");
-	if( ! run_command(cmd) )
-	{
-	    info = g_strdup_printf(_("Failed adding user: %s\n"), server_user);
-	    show_info(info);
-	    g_free(info);
-	    return;
-	}
-	g_free(cmd);
+        cmd = g_strdup_printf("%s '%s' -g '%s' -d /dev/null -c '%s' -s /dev/null",
+                        ADDUSER, server_user, server_group, "GAdmin-OpenVPN-Server");
+        if( ! run_command(cmd) )
+        {
+            info = g_strdup_printf(_("Failed adding user: %s\n"), server_user);
+            show_info(info);
+            g_free(info);
+            return;
+        }
+        g_free(cmd);
     }
 
 
-    /* Combos */
+    /* Combos... */
 
     /* Protocol */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[0]));
     if( active_index == 0 )
-      proto = g_strdup_printf("proto tcp");
+        proto = g_strdup_printf("proto tcp");
     else
-      proto = g_strdup_printf("proto udp");
+        proto = g_strdup_printf("proto udp");
 
     /* Tap device */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[1]));
     if( active_index == 0 )
-      tap_dev = g_strdup_printf("tap0");
+        tap_dev = g_strdup_printf("tap0");
     if( active_index == 1 )
-      tap_dev = g_strdup_printf("tap1");
+        tap_dev = g_strdup_printf("tap1");
     if( active_index == 2 )
-      tap_dev = g_strdup_printf("tap2");
+        tap_dev = g_strdup_printf("tap2");
     if( active_index == 3 )
-      tap_dev = g_strdup_printf("tap3");
+        tap_dev = g_strdup_printf("tap3");
 
     /* Require authentication. Also adds username-as-common-name so per user config is possible. */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[2]));
@@ -234,34 +232,34 @@ void apply_server_settings(struct w *widgets)
     /* Cipher */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[3]));
     if( active_index == 0 )
-      cipher = g_strdup_printf("cipher BF-CBC\n");       /* BlowFish */
+        cipher = g_strdup_printf("cipher BF-CBC\n");       /* BlowFish */
     if( active_index == 1 )
-      cipher = g_strdup_printf("cipher AES-128-CBC\n");  /* AES 128 */
+        cipher = g_strdup_printf("cipher AES-128-CBC\n");  /* AES 128 */
     if( active_index == 2 )
-      cipher = g_strdup_printf("cipher AES-256-CBC\n");  /* AES 256 */
+        cipher = g_strdup_printf("cipher AES-256-CBC\n");  /* AES 256 */
     if( active_index == 3 )
-      cipher = g_strdup_printf("cipher DES-EDE3-CBC\n"); /* Triple-DES */
+        cipher = g_strdup_printf("cipher DES-EDE3-CBC\n"); /* Triple-DES */
 
     /* Client-to-client */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[4]));
     if( active_index == 0 )
-      client_to_client = g_strdup_printf("\n"); /* "No" */
+        client_to_client = g_strdup_printf("\n"); /* "No" */
     else
-      client_to_client = g_strdup_printf("client-to-client\n");
+        client_to_client = g_strdup_printf("client-to-client\n");
 
     /* Redirect-gateway */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[5]));
     if( active_index == 0 )
-      redirect_gateway = g_strdup_printf("\n");
+        redirect_gateway = g_strdup_printf("\n");
     else
-      redirect_gateway = g_strdup_printf("push \"redirect-gateway\"\n");
+        redirect_gateway = g_strdup_printf("push \"redirect-gateway\"\n");
 
     /* Compression */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[6]));
     if( active_index == 0 )
-      compression = g_strdup_printf("\n");
+        compression = g_strdup_printf("\n");
     else
-      compression = g_strdup_printf("comp-lzo\n");
+        compression = g_strdup_printf("comp-lzo\n");
 
 
     /* Chroot is standard */
@@ -271,89 +269,89 @@ void apply_server_settings(struct w *widgets)
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[7]));
     if( active_index == 1 )
     {
-	/* Get the LAN network address. Snip at the last dot. */
-	lan_net_addr = g_strdup_printf("%s", lan_iface_address);
-	for(i=strlen(lan_net_addr)-1; lan_net_addr[i]!='\0'; i--)
-	if( lan_net_addr[i]=='.')
-	{
-	    lan_net_addr[i+1]='0';
-	    lan_net_addr[i+2]='\0';
-	    break;
-	}
-	share_internet = g_strconcat(
-	"	", IP_FORWARD_CMD_START, "\n",
-	"	iptables -t nat -A POSTROUTING -o ", external_iface_name, " -j MASQUERADE\n",
-	NULL);
+        /* Get the LAN network address. Snip at the last dot. */
+        lan_net_addr = g_strdup_printf("%s", lan_iface_address);
+        for(i=strlen(lan_net_addr)-1; lan_net_addr[i]!='\0'; i--)
+        if( lan_net_addr[i]=='.')
+        {
+            lan_net_addr[i+1]='0';
+            lan_net_addr[i+2]='\0';
+            break;
+        }
+        share_internet = g_strconcat(
+        "	", IP_FORWARD_CMD_START, "\n",
+        "	iptables -t nat -A POSTROUTING -o ", external_iface_name, " -j MASQUERADE\n",
+        NULL);
 
-	g_free(lan_net_addr);
+        g_free(lan_net_addr);
     }
     else
-      share_internet = g_strdup_printf("\t%s\n", IP_FORWARD_CMD_STOP);
+        share_internet = g_strdup_printf("\t%s\n", IP_FORWARD_CMD_STOP);
 
 
     /* If Firestarter is used, add sysinit script parts and setup firestarter. */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[8]));
     if( active_index == 1 )
     {
-	/* Add Firestarter iptables tap+ settings to the user-pre file if it exists */
-	add_firestarter_user_pre();
+        /* Add Firestarter iptables tap+ settings to the user-pre file if it exists */
+        add_firestarter_user_pre();
 
-	/* Start script part for Firestarter including a sleep loop with a timeout */
-	firestarter_start = g_strconcat(
-	"	# Start Firestarter if its not running.\n",
-	"	if [ ! -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
-	"	   # Wait a while for the LAN interface to come up so that firestarter can start.\n",
-	"	   count=0\n",
-	"	   max_wait=15\n",
-	"	   while [ 1 ]; do\n",
-	"		sleep 1\n",
-	"		let \"count+=1\"\n",
-	"		ip addr show ", lan_iface_name, " | grep -q \"inet \" && break\n",
-	"		echo \"Waiting for interfaces to come up...\"\n",
-	"		if [ $count -gt $max_wait ]; then\n",
-	"		   echo \"Wait for interfaces - Giving up.\"\n",
+        /* Start script part for Firestarter including a sleep loop with a timeout */
+        firestarter_start = g_strconcat(
+        "	# Start Firestarter if its not running.\n",
+        "	if [ ! -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
+        "	   # Wait a while for the LAN interface to come up so that firestarter can start.\n",
+        "	   count=0\n",
+        "	   max_wait=15\n",
+        "	   while [ 1 ]; do\n",
+        "		sleep 1\n",
+        "		let \"count+=1\"\n",
+        "		ip addr show ", lan_iface_name, " | grep -q \"inet \" && break\n",
+        "		echo \"Waiting for interfaces to come up...\"\n",
+        "		if [ $count -gt $max_wait ]; then\n",
+        "		   echo \"Wait for interfaces - Giving up.\"\n",
         "		   break\n",
-	"	   	fi\n",
-	"	   done\n",
-	"    	   ", FIRESTARTER_BINARY, " -s\n",
-	"	fi\n",
-	"\n",
-	share_internet,
-	NULL);
+        "	   	fi\n",
+        "	   done\n",
+        "    	   ", FIRESTARTER_BINARY, " -s\n",
+        "	fi\n",
+        "\n",
+        share_internet,
+        NULL);
 
-	/* Stop script part for Firestarter */
-	firestarter_stop = g_strconcat(
-	"	# Stop Firestarter if its running.\n",
-	"	if [ -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
-	"    	   ", FIRESTARTER_BINARY, " -p\n",
-	"	fi\n",
-	NULL);
-	
-	non_firestarter_start = g_strdup_printf("\n");
-	non_firestarter_stop  = g_strdup_printf("\n");
+        /* Stop script part for Firestarter */
+        firestarter_stop = g_strconcat(
+        "	# Stop Firestarter if its running.\n",
+        "	if [ -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
+        "    	   ", FIRESTARTER_BINARY, " -p\n",
+        "	fi\n",
+        NULL);
+
+        non_firestarter_start = g_strdup_printf("\n");
+        non_firestarter_stop  = g_strdup_printf("\n");
     }
     else
     {
-	/* Instead of firestarter configuring iptables, we do it. */
-	non_firestarter_start = g_strconcat(
-	"	# Run some iptable rules for the LAN network and VPN-clients.\n",
-	"	iptables -A INPUT   -i tap+ -j ACCEPT\n",
-	"	iptables -A OUTPUT  -o tap+ -j ACCEPT\n",
-	"	iptables -A FORWARD -i tap+ -j ACCEPT\n",
-	share_internet,
-	NULL);
+        /* Instead of firestarter configuring iptables, we do it. */
+        non_firestarter_start = g_strconcat(
+        "	# Run some iptable rules for the LAN network and VPN-clients.\n",
+        "	iptables -A INPUT   -i tap+ -j ACCEPT\n",
+        "	iptables -A OUTPUT  -o tap+ -j ACCEPT\n",
+        "	iptables -A FORWARD -i tap+ -j ACCEPT\n",
+        share_internet,
+        NULL);
 
-	/* Disallow input and output on tap interfaces.
-	   Restart the LAN network interface. Doesnt work otherwise. */
-	non_firestarter_stop = g_strconcat(
-	"	iptables -D INPUT   -i tap+ -j ACCEPT\n",
-	"	iptables -D OUTPUT  -o tap+ -j ACCEPT\n",
-	"	iptables -D FORWARD -i tap+ -j ACCEPT\n",
-	NULL);
-	/* Dont remove any internet sharing. */
-	
-	firestarter_start = g_strdup_printf("\n");
-	firestarter_stop  = g_strdup_printf("\n");
+        /* Disallow input and output on tap interfaces.
+           Restart the LAN network interface. Doesnt work otherwise. */
+        non_firestarter_stop = g_strconcat(
+        "	iptables -D INPUT   -i tap+ -j ACCEPT\n",
+        "	iptables -D OUTPUT  -o tap+ -j ACCEPT\n",
+        "	iptables -D FORWARD -i tap+ -j ACCEPT\n",
+        NULL);
+        /* Dont remove any internet sharing. */
+
+        firestarter_start = g_strdup_printf("\n");
+        firestarter_stop  = g_strdup_printf("\n");
     }
     g_free(share_internet);
 
@@ -361,39 +359,38 @@ void apply_server_settings(struct w *widgets)
     /* Client DNS servers */
     if( client_dns == NULL || strlen(client_dns) < 20 )
     {
-	client_dns_line = g_strdup_printf("\n");
+        client_dns_line = g_strdup_printf("\n");
     }
     else
     {
-	/* Space separated list of DNS's in the entry. */
-	tmp1 = allocate(1024);
-	tmp2 = allocate(1024*3);
+        /* Space separated list of DNS's in the entry. */
+        tmp1 = allocate(1024);
+        tmp2 = allocate(1024*3);
 
-	for(i=0; client_dns[i]!='\0'; i++)
-	if( client_dns[i]!=' ' && client_dns[i]!='\t' )
-	{
-	    snprintf(tmp1, 1000, "%s", &client_dns[i]);
+        for(i=0; client_dns[i]!='\0'; i++)
+        if( client_dns[i]!=' ' && client_dns[i]!='\t' )
+        {
+            snprintf(tmp1, 1000, "%s", &client_dns[i]);
 
-	    /* Snip after the new dns. */
-	    for(z=0; strlen(tmp1); z++)
-	    if( tmp1[z]==' ' || tmp1[z]=='\t' || tmp1[z]=='\0' )
-	    {
-		tmp1[z]='\0';
+            /* Snip after the new dns. */
+            for(z=0; strlen(tmp1); z++)
+            if( tmp1[z]==' ' || tmp1[z]=='\t' || tmp1[z]=='\0' )
+            {
+                tmp1[z]='\0';
+                strcat(tmp2, "push \"dhcp-option DNS ");
+                strcat(tmp2, tmp1);
+                strcat(tmp2, "\"\n");
+                break;
+            }
+            for(i=i; client_dns[i]!='\0'; i++)
+              if( client_dns[i]==' ' || client_dns[i]=='\t' )
+                break;
+        }
 
-		strcat(tmp2, "push \"dhcp-option DNS ");
-		strcat(tmp2, tmp1);
-		strcat(tmp2, "\"\n");
-		break;
-	    }
-	    for(i=i; client_dns[i]!='\0'; i++)
-	      if( client_dns[i]==' ' || client_dns[i]=='\t' )
-	        break;
-	}
+        client_dns_line = g_strdup_printf("%s", tmp2);
 
-	client_dns_line = g_strdup_printf("%s", tmp2);
-	
-	free(tmp1);
-	free(tmp2);
+        free(tmp1);
+        free(tmp2);
     }
 
 
@@ -402,23 +399,23 @@ void apply_server_settings(struct w *widgets)
     openvpn_server_conf = g_strdup_printf("%s/server/gadmin-openvpn-server.conf", OPENVPN_SYSCONF_DIR);
     if((fp=fopen(openvpn_server_conf, "w+"))==NULL)
     {
-	info = g_strdup_printf(_("Can not write openvpn server configuration here: \n%s\n"), openvpn_server_conf);
-	show_info(info);
-	g_free(info);
-	g_free(openvpn_server_conf);
-	g_free(proto);
-	g_free(tap_dev);
-	g_free(require_auth);
-	g_free(cipher);
-	g_free(client_to_client);
-	g_free(redirect_gateway);
-	g_free(compression);
-	g_free(firestarter_start);
-	g_free(firestarter_stop);
-	g_free(non_firestarter_start);
-	g_free(non_firestarter_stop);
-	g_free(client_auth_line);
-	g_free(client_dns_line);
+        info = g_strdup_printf(_("Can not write openvpn server configuration here: \n%s\n"), openvpn_server_conf);
+        show_info(info);
+        g_free(info);
+        g_free(openvpn_server_conf);
+        g_free(proto);
+        g_free(tap_dev);
+        g_free(require_auth);
+        g_free(cipher);
+        g_free(client_to_client);
+        g_free(redirect_gateway);
+        g_free(compression);
+        g_free(firestarter_start);
+        g_free(firestarter_stop);
+        g_free(non_firestarter_start);
+        g_free(non_firestarter_stop);
+        g_free(client_auth_line);
+        g_free(client_dns_line);
         return;
     }
 
@@ -459,31 +456,30 @@ void apply_server_settings(struct w *widgets)
     fclose(fp);
 
     if( openvpn_server_conf!=NULL )
-      g_free(openvpn_server_conf);
+        g_free(openvpn_server_conf);
     if( client_dns_line!=NULL )
-      g_free(client_dns_line);
-
+        g_free(client_dns_line);
 
     /* Write the client configuration */
     openvpn_client_conf = g_strdup_printf("%s/server/client/gadmin-openvpn-client.conf", OPENVPN_SYSCONF_DIR);
     if((fp=fopen(openvpn_client_conf, "w+"))==NULL)
     {
-	info = g_strdup_printf(_("Can not write openvpn client configuration here: \n%s\n"), openvpn_client_conf);
-	show_info(info);
-	g_free(info);
-	g_free(openvpn_client_conf);
-	g_free(proto);
-	g_free(tap_dev);
-	g_free(require_auth);
-	g_free(cipher);
-	g_free(client_to_client);
-	g_free(redirect_gateway);
-	g_free(compression);
-	g_free(firestarter_start);
-	g_free(firestarter_stop);
-	g_free(non_firestarter_start);
-	g_free(non_firestarter_stop);
-	g_free(client_auth_line);
+        info = g_strdup_printf(_("Can not write openvpn client configuration here: \n%s\n"), openvpn_client_conf);
+        show_info(info);
+        g_free(info);
+        g_free(openvpn_client_conf);
+        g_free(proto);
+        g_free(tap_dev);
+        g_free(require_auth);
+        g_free(cipher);
+        g_free(client_to_client);
+        g_free(redirect_gateway);
+        g_free(compression);
+        g_free(firestarter_start);
+        g_free(firestarter_stop);
+        g_free(non_firestarter_start);
+        g_free(non_firestarter_stop);
+        g_free(client_auth_line);
         return;
     }
 
@@ -496,7 +492,6 @@ void apply_server_settings(struct w *widgets)
     "ca   certs/cacert.pem\n",
     "cert certs/cert.pem\n",
     "key  certs/key.pem\n",
-    "dh   certs/dh.pem\n",
     "tls-auth certs/ta.key 1\n",
     client_auth_line,
     cipher,
@@ -631,16 +626,16 @@ void apply_server_settings(struct w *widgets)
     sysinit_script_path = g_strdup_printf("%s/gadmin-openvpn-server", SYSINIT_SCRIPTS_DIR);
     if((fp=fopen(sysinit_script_path, "w+"))==NULL)
     {
-	info = g_strdup_printf(_("Can not write openvpn server sysinit script here: \n%s\n"), sysinit_script_path);
-	show_info(info);
-	g_free(info);
-	g_free(sysinit_start_script);
-	g_free(sysinit_script_path);
-	g_free(tap_dev);
-	g_free(firestarter_start);
-	g_free(firestarter_stop);
-	g_free(non_firestarter_start);
-	g_free(non_firestarter_stop);
+        info = g_strdup_printf(_("Can not write openvpn server sysinit script here: \n%s\n"), sysinit_script_path);
+        show_info(info);
+        g_free(info);
+        g_free(sysinit_start_script);
+        g_free(sysinit_script_path);
+        g_free(tap_dev);
+        g_free(firestarter_start);
+        g_free(firestarter_stop);
+        g_free(non_firestarter_start);
+        g_free(non_firestarter_stop);
         return;
     }
     fputs(sysinit_start_script, fp);
@@ -650,7 +645,7 @@ void apply_server_settings(struct w *widgets)
     cmd = g_strdup_printf("chmod 755 %s", sysinit_script_path);
     if( ! run_command(cmd) )
     {
-	printf("Show popup, error chmodding sysinit script.\n");
+        printf("Show popup, error chmodding sysinit script.\n");
     }
     g_free(cmd);
 
@@ -670,5 +665,5 @@ void apply_server_settings(struct w *widgets)
     populate_conf_tab(widgets);
 
     if( activated )
-      reread_conf(widgets);
+        reread_conf(widgets);
 }
