@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,13 +56,15 @@ void create_server_settings(struct w *widgets)
     tooltips = gtk_tooltips_new();
 
     /* External interface name */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" External interface name: "), 0,1,a,b,entry_size);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" External interface name: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], 
-    _("The name of the internet connected interface, IE: eth0"), NULL);
+            _("The name of the internet connected interface, IE: eth0"), NULL);
     a++; b++; ent++;
 
     /* External address */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" External address: "), 0,1,a,b,entry_size);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" External address: "), 0,1,a,b,entry_size);
 
     combo_text = g_strconcat(
     _("The external address clients will be connecting to such as:\nvpn.example.org or an IP-address.\n"),
@@ -74,42 +76,50 @@ void create_server_settings(struct w *widgets)
     a++; b++; ent++;
 
     /* Server port */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table), _(" Server port: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("The port VPN clients should connect to."), NULL);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Server port: "), 0,1,a,b,50);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin],
+            _("The port VPN clients should connect to."), NULL);
     a++; b++; spin++;
 
     /* LAN interface name */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" LAN interface name: "), 0,1,a,b,entry_size);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" LAN interface name: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], 
-    _("The name of the LAN network interface, IE: eth1"), NULL);
+            _("The name of the LAN network interface, IE: eth1"), NULL);
     a++; b++; ent++;
 
     /* LAN interface address */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" LAN interface address: "), 0,1,a,b,entry_size);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" LAN interface address: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], 
     _("IE: 10.8.0.100\nYour LAN should not have the same network address as connecting clients commonly have, IE: 192.168.0.1 or 10.0.0.1 Also change this setting in your DHCP server and firewall."), NULL);
     a++; b++; ent++;
 
     /* LAN Subnet mask */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" LAN subnet mask: "), 0,1,a,b,entry_size);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" LAN subnet mask: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], 
     _("IE: 255.255.0.0"), NULL);
     a++; b++; ent++;
 
     /* LAN Broadcast address */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" LAN broadcast address: "), 0,1,a,b,entry_size);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" LAN broadcast address: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], 
-    _("IE: 10.8.0.255"), NULL);
+    _("IE: 10.8.255.255"), NULL);
     a++; b++; ent++;
 
     /* VPN Clients address pool */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Client address range: "), 0,1,a,b,entry_size);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Client address range: "), 0,1,a,b,entry_size);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], 
     _("VPN clients are assigned IP-addresses on the LAN in this range, IE: 10.8.0.120 10.8.255.254"), NULL);
     a++; b++; ent++;
 
     /* Protocol UDP/TCP */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Protocol: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Protocol: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("TCP"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -121,7 +131,8 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* The TAP interface to create and use */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" TAP Device: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" TAP Device: "), 0,1,a,b,50);
     combo_text = g_strdup_printf("Tap0");
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -141,7 +152,8 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Require username and password authentication */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Require authentication: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Require authentication: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("No"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -153,7 +165,8 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Encryption type: BlowFish, AES or Triple-DES */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Encryption type: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Encryption type: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("BlowFish"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -173,7 +186,8 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Allow client to client to see eachother */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Clients see eachother: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Clients see eachother: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("No"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -185,7 +199,8 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Push "redirect-gateway" */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Tunnel all client traffic: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Tunnel all client traffic: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("No"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -197,7 +212,8 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Use compression */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Use compression: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Use compression: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("No"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -209,7 +225,8 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Share internet */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Share internet: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Share internet: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("No"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -221,7 +238,8 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Using Firestarter */
-    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table), _(" Using Firestarter: "), 0,1,a,b,50);
+    widgets->server_set_combo[comb] = make_short_combo_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Using Firestarter: "), 0,1,a,b,50);
     combo_text = g_strdup_printf(_("No"));
     utf8 = g_locale_to_utf8(combo_text, strlen(combo_text), NULL, NULL, NULL);
     gtk_combo_box_append_text(GTK_COMBO_BOX(widgets->server_set_combo[comb]), utf8);
@@ -233,42 +251,53 @@ void create_server_settings(struct w *widgets)
     a++; b++; comb++;
 
     /* Max connections */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Max connections: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Limits the amount of concurrent connections. 0 means no limit."), NULL);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Max connections: "), 0,1,a,b,50);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin],
+            _("Limits the amount of concurrent connections. 0 means no limit."), NULL);
     a++; b++; spin++;
 
     /* Log level (verb 3) */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Log level: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Log verbosity level."), NULL);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Log level: "), 0,1,a,b,50);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin],
+            _("Log verbosity level."), NULL);
     a++; b++; spin++;
 
     /* Ping interval */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Ping interval: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Ping interval in seconds."), NULL);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Ping interval: "), 0,1,a,b,50);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin],
+            _("Ping interval in seconds."), NULL);
     a++; b++; spin++;
 
     /* Ping timeout */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Ping timeout: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Number of seconds a client has to reply to a ping before the server closes the connection."), NULL);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Ping timeout: "), 0,1,a,b,50);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin],
+            _("Number of seconds a client has to reply to a ping before the server closes the connection."), NULL);
     a++; b++; spin++;
 
 
     /* Server user */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The server runs as this user: "), 0,1,a,b,200);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" The server runs as this user: "), 0,1,a,b,200);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
-    _("The server drops root privileges and runs as this user"), NULL);
+            _("The server drops root privileges and runs as this user"), NULL);
     a++; b++; ent++;
 
     /* Server group */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The server runs as this group: "), 0,1,a,b,200);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" The server runs as this group: "), 0,1,a,b,200);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
-    _("The server drops root privileges and runs as this group"), NULL);
+            _("The server drops root privileges and runs as this group"), NULL);
     a++; b++; ent++;
 
     /* Client DNS servers */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Client DNS servers: "), 0,1,a,b,200);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Client DNS servers: "), 0,1,a,b,200);
     gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
-    _("If not empty the server will push this space separated list of DNS-addresses to the VPN-clients."), NULL);
+            _("If not empty the server will push this space separated list of DNS-addresses to the VPN-clients."), NULL);
     a++; b++; ent++;
 
     /* A hseparator */
@@ -276,62 +305,84 @@ void create_server_settings(struct w *widgets)
     a++; b++;
 
     /* The signed certificate settings */
-    make_3columns_label(GTK_TABLE(widgets->srv_set_table), _(" Signed certificate settings: "), 0,1,a,b);
+    make_3columns_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Signed certificate settings: "), 0,1,a,b);
     a++; b++;
 
     /* This servers DNS name or IP-Address */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Server address: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("This servers DNS name or IP address"), NULL);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Server address: "), 0,1,a,b,200);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+            _("This servers DNS name or IP address"), NULL);
     a++; b++; ent++;
 
     /* Email address */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Email address: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The administrators email address"), NULL);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Email address: "), 0,1,a,b,200);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+            _("The administrators email address"), NULL);
     a++; b++; ent++;
 
     /* Country */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Country: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("A country"), NULL);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Country: "), 0,1,a,b,200);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+            _("A country"), NULL);
     a++; b++; ent++;
 
     /* City or town */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" City or town: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("A city or a town"), NULL);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" City or town: "), 0,1,a,b,200);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+            _("A city or a town"), NULL);
     a++; b++; ent++;
 
     /* Organization */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Organization: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("Some organization"), NULL);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Organization: "), 0,1,a,b,200);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+            _("Some organization"), NULL);
     a++; b++; ent++;
 
     /* Organization unit */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Organization unit: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("A department within the organization"), NULL);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Organization unit: "), 0,1,a,b,200);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+            _("A department within the organization"), NULL);
     a++; b++; ent++;
 
     /* Password */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Password: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("A password"), NULL);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Password: "), 0,1,a,b,200);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+            _("A password"), NULL);
     a++; b++; ent++;
 
     /* Number of encryption bits (Min value = 384) */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Encryption bits: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Number of bits in the generated certificate"), NULL);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Encryption bits: "), 0,1,a,b,50);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin],
+            _("Number of bits in the generated certificate"), NULL);
     gtk_spin_button_set_range(GTK_SPIN_BUTTON(widgets->server_set_spinbutton[spin]), 384, 999999);
     a++; b++; spin++;
 
     /* Number of days the certificate is valid */
-    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),_(" Days valid: "), 0,1,a,b,50);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin], _("Number of days the certificate is valid"), NULL);
+    widgets->server_set_spinbutton[spin] = make_short_spinbutton_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Days valid: "), 0,1,a,b,50);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_spinbutton[spin],
+            _("Number of days the certificate is valid"), NULL);
     a++; b++; spin++;
 
     /* Countrycode */
-    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Country code: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The country code, IE: SV, DK, EN, US"), NULL);
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Country code: "), 0,1,a,b,200);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+            _("The country code, IE: SV, DK, EN, US"), NULL);
     a++; b++; ent++;
 
     /* A progress bar */
-    widgets->gen_cert_progressbar = make_progressbar_with_label(GTK_TABLE(widgets->srv_set_table), _(" Generate certificate: "), 0,1,a,b,210);
+    widgets->gen_cert_progressbar = make_progressbar_with_label(GTK_TABLE(widgets->srv_set_table),
+            _(" Generate certificate: "), 0,1,a,b,210);
     gtk_widget_set_sensitive(widgets->gen_cert_progressbar, FALSE);
 
     /* The progress bar looks nicer if its blue from start */
