@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,7 +31,6 @@
 /* For tolower.. */
 #include <ctype.h>
 #include "widgets.h"
-#include "chars_are_digits.h"
 #include "allocate.h"
 #include "functions.h"
 #include "show_info.h"
@@ -60,7 +59,7 @@ int cmplowercase(char *buf, char *cmpstring)
 
     /* Ignore single newline chars */
     if( strlen(buf) < 2 )
-      return retval;
+        return retval;
 
     newbuf = allocate(strlen(buf)+1);
     /* Exits if it cant allocate */
@@ -70,13 +69,63 @@ int cmplowercase(char *buf, char *cmpstring)
         *p = tolower(*p);
 
     if( strstr(newbuf, cmpstring) )
-      retval = 1;
+        retval = 1;
 
     free(newbuf);
 
     return retval;
 }
 
+int chars_are_digits(char *buf)
+{
+    int i=0, match=0;
+    for(i=0; buf[i]!='\0'; i++)
+    {
+        if( buf[i]=='\n' || buf[i]=='\r')
+        {
+            i--;
+            break;
+        }
+        if( buf[i]=='0' || buf[i]=='1' || buf[i]=='2' || buf[i]=='3' || buf[i]=='4' 
+        || buf[i]=='5' || buf[i]=='6' || buf[i]=='7' || buf[i]=='8' || buf[i]=='9' )
+            match++;	 
+    }
+    if( match && match==i )
+        return 1;
+    else
+       return 0;    
+}
+
+int commented(char *line)
+{
+    int i, ret = 0;
+
+    if( line == NULL || strlen(line) < 1 )
+        return ret;
+
+    for(i=0; line[i]!='\0'; i++)
+    {
+        if( i > 9000 )
+        {
+            ret = 1;
+            break;
+        }
+
+        /* Skip whitespace */
+        if( line[i]==' ' || line[i]=='\t' )
+            continue;
+        
+        /* If the first char thats not whitespace is '#' or ';'
+           then the line is commented out */
+        if( line[i]=='#' || line[i]==';' )
+          ret = 1;
+        else
+          ret = 0;
+
+        break;
+    }
+    return ret;
+}
 
 int
 user_exists(G_CONST_RETURN gchar *username)
