@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -72,7 +72,7 @@ void generate_cert(struct w *widgets)
     val=0.0;
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), val);
     while(gtk_events_pending())
-	  gtk_main_iteration();
+        gtk_main_iteration();
 
 
     /* Show error if a value is missing */
@@ -80,22 +80,22 @@ void generate_cert(struct w *widgets)
     ||  strlen(days)     == 0 || strlen(country) == 0 || strlen(country)   > 2 || strlen(state)    == 0
     ||  strlen(city)     == 0 || strlen(org)     == 0 || strlen(org_unit) == 0 || strlen(cert_dir)  < 7 )
     {
-	info = g_strdup_printf(_("Every certificate field must be filled in.\n"));
-	show_info(info);
-	g_free(info);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Every certificate field must be filled in.\n"));
+        show_info(info);
+        g_free(info);
+        g_free(cert_dir);
+        return;
     }
 
     /* The password field can not contain spaces */
     for(i=0; password[i]!='\0'; i++)
     if( password[i]==' ' || password[i]=='\n' || password[i]=='\r' || password[i]=='\t' )
     {
-	info = g_strdup_printf(_("The password field cant contain any spaces or newline chars.\n"));
-	show_info(info);
-	g_free(info);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("The password field cant contain any spaces or newline chars.\n"));
+        show_info(info);
+        g_free(info);
+        g_free(cert_dir);
+        return;
     }
 
 
@@ -103,12 +103,12 @@ void generate_cert(struct w *widgets)
     cmd = g_strdup_printf("mkdir -p %s && chmod 700 %s", cert_dir, cert_dir);
     if( ! run_command(cmd) )
     {
-	info = g_strdup_printf(_("Can not create secure certificate directory with command:\n%s\n"), cmd);
-	show_info(info);
-	g_free(info);
-	g_free(cmd);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Can not create secure certificate directory with command:\n%s\n"), cmd);
+        show_info(info);
+        g_free(info);
+        g_free(cmd);
+        g_free(cert_dir);
+        return;
     }
     g_free(cmd);
 
@@ -117,19 +117,19 @@ void generate_cert(struct w *widgets)
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), _("Setting up environment"));
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), val);
     while(gtk_events_pending())
-	  gtk_main_iteration();
+        gtk_main_iteration();
     sleep(1);
 
     /* Create a new gadmin-openvpn-openssl.conf with selected values. */
     openssl_config_path = g_strdup_printf("%s/gadmin-openvpn-openssl.conf", cert_dir);
     if((fp=fopen(openssl_config_path, "w+"))==NULL)
     {
-	info = g_strdup_printf(_("Error writing gadmin-openvpn-openssl.conf here: \n%s\n"), openssl_config_path);
-	show_info(info);
-	g_free(info);
-	g_free(openssl_config_path);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error writing gadmin-openvpn-openssl.conf here: \n%s\n"), openssl_config_path);
+        show_info(info);
+        g_free(info);
+        g_free(openssl_config_path);
+        g_free(cert_dir);
+        return;
     }
     fclose(fp);
 
@@ -137,25 +137,25 @@ void generate_cert(struct w *widgets)
     cmd = g_strdup_printf("chmod 600 %s", openssl_config_path);
     if( ! run_command(cmd) )
     {
-	info = g_strdup_printf(_("Error: Could not chmod:\n%s\n"), openssl_config_path);
-	show_info(info);
-	g_free(info);
-	g_free(cmd);
-	g_free(openssl_config_path);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error: Could not chmod:\n%s\n"), openssl_config_path);
+        show_info(info);
+        g_free(info);
+        g_free(cmd);
+        g_free(openssl_config_path);
+        g_free(cert_dir);
+        return;
     }
     g_free(cmd);
 
     /* Write the new openssl conf contents */
     if((fp=fopen(openssl_config_path, "w"))==NULL)
     {
-	info = g_strdup_printf(_("Error writing gadmin-openvpn-openssl.conf here: \n%s\n"), openssl_config_path);
-	show_info(info);
-	g_free(info);
-	g_free(openssl_config_path);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error writing gadmin-openvpn-openssl.conf here: \n%s\n"), openssl_config_path);
+        show_info(info);
+        g_free(info);
+        g_free(openssl_config_path);
+        g_free(cert_dir);
+        return;
     }
 
     config = g_strconcat("\n",
@@ -231,40 +231,26 @@ void generate_cert(struct w *widgets)
     passfile = g_strdup_printf("%s/passfile", cert_dir);
     if((fp=fopen(passfile, "w+"))==NULL)
     {
-	info = g_strdup_printf(_("Error writing openssl password file here:\n%s\n"), passfile);
-	show_info(info);
-	g_free(info);
-	g_free(passfile);
-	g_free(openssl_config_path);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error writing openssl password file here:\n%s\n"), passfile);
+        show_info(info);
+        g_free(info);
+        g_free(passfile);
+        g_free(openssl_config_path);
+        g_free(cert_dir);
+        return;
     }
     fclose(fp);
 
-    /* Secure the password file. */
-/*    cmd = g_strdup_printf("chmod 750 %s", passfile);
-    if( ! run_command(cmd) )
-    {
-	info = g_strdup_printf(_("Error: Could not chmod:\n%s\n"), openssl_config_path);
-	show_info(info);
-	g_free(info);
-	g_free(cmd);
-	g_free(passfile);
-	g_free(openssl_config_path);
-	return;
-    }
-    g_free(cmd);
-*/
 
     if((fp=fopen(passfile, "w"))==NULL)
     {
-	info = g_strdup_printf(_("Error writing openssl password file here:\n%s\n"), passfile);
-	show_info(info);
-	g_free(info);
-	g_free(passfile);
-	g_free(openssl_config_path);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error writing openssl password file here:\n%s\n"), passfile);
+        show_info(info);
+        g_free(info);
+        g_free(passfile);
+        g_free(openssl_config_path);
+        g_free(cert_dir);
+        return;
     }
     fputs(password, fp);
     fputs("\n", fp);
@@ -273,15 +259,14 @@ void generate_cert(struct w *widgets)
     fclose(fp);
 
 
-
     /* The last openssl command requires openssl conf to be in the same work dir. */
     if( chdir(cert_dir) != 0 )
     {
-	info = g_strdup_printf(_("Error changing to certificate directory: \n%s\n"), cert_dir);
-	show_info(info);
-	g_free(info);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error changing to certificate directory: \n%s\n"), cert_dir);
+        show_info(info);
+        g_free(info);
+        g_free(cert_dir);
+        return;
     }
 
 
@@ -289,25 +274,25 @@ void generate_cert(struct w *widgets)
     script_path = g_strdup_printf("%s/create_certs.sh", cert_dir);
     if((fp=fopen(script_path, "w+"))==NULL)
     {
-	info = g_strdup_printf(_("Error writing gadmin-openvpn-openssl.conf here: \n%s\n"), script_path);
-	show_info(info);
-	g_free(info);
-	g_free(script_path);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error writing gadmin-openvpn-openssl.conf here: \n%s\n"), script_path);
+        show_info(info);
+        g_free(info);
+        g_free(script_path);
+        g_free(cert_dir);
+        return;
     }
     openssl_script = g_strconcat("",
-    "#!/bin/bash\n\n",
+            "#!/bin/bash\n\n",
 
-    "rm -f index*\n",
-    "touch index.txt\n",
-    "rm -f serial*\n",
-    "echo '01' > serial\n",
-    "rm -f *.pem\n",
-    "openssl req -new -x509 -days ", days,
-    " -extensions v3_ca -keyout cakey.pem -out cacert.pem -config ",
-    openssl_config_path, " -batch -passout file:", passfile,"\n\n",
-    NULL);
+            "rm -f index*\n",
+            "touch index.txt\n",
+            "rm -f serial*\n",
+            "echo '01' > serial\n",
+            "rm -f *.pem\n",
+            "openssl req -new -x509 -days ", days,
+            " -extensions v3_ca -keyout cakey.pem -out cacert.pem -config ",
+            openssl_config_path, " -batch -passout file:", passfile,"\n\n",
+            NULL);
     fputs(openssl_script, fp);
     fclose(fp);
     g_free(openssl_script);
@@ -317,38 +302,38 @@ void generate_cert(struct w *widgets)
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), _("Creating certificate authority"));
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), val);
     while(gtk_events_pending())
-	  gtk_main_iteration();
+        gtk_main_iteration();
     sleep(1);
 
     /* Run the first openssl script */
     cmd = g_strdup_printf("chmod 755 %s && %s", script_path, script_path);
     if( ! run_command(cmd) )
     {
-	info = g_strdup_printf(_("Error running openssl script 1:\n%s\n"), script_path);
-	show_info(info);
-	g_free(info);
-	g_free(script_path);
-	g_free(cmd);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error running openssl script 1:\n%s\n"), script_path);
+        show_info(info);
+        g_free(info);
+        g_free(script_path);
+        g_free(cmd);
+        g_free(cert_dir);
+        return;
     }
     g_free(cmd);
 
     /* Create the second openssl script */
     if((fp=fopen(script_path, "w+"))==NULL)
     {
-	info = g_strdup_printf(_("Error writing gadmin-openvpn-openssl.conf here: \n%s\n"), script_path);
-	show_info(info);
-	g_free(info);
-	g_free(script_path);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error writing gadmin-openvpn-openssl.conf here: \n%s\n"), script_path);
+        show_info(info);
+        g_free(info);
+        g_free(script_path);
+        g_free(cert_dir);
+        return;
     }
     openssl_script = g_strconcat("",
-    "#!/bin/bash\n\n",
+        "#!/bin/bash\n\n",
 
-    "openssl req -new -nodes -out req.pem -config ", openssl_config_path, " -batch -passout file:", passfile, "\n\n",
-    NULL);
+        "openssl req -new -nodes -out req.pem -config ", openssl_config_path, " -batch -passout file:", passfile, "\n\n",
+        NULL);
     fputs(openssl_script, fp);
     fclose(fp);
     g_free(openssl_script);
@@ -358,41 +343,41 @@ void generate_cert(struct w *widgets)
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), _("Creating client certificate"));
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), val);
     while(gtk_events_pending())
-	  gtk_main_iteration();
+        gtk_main_iteration();
     sleep(1);
 
     /* Run the second openssl script */
     cmd = g_strdup_printf("chmod 755 %s && %s", script_path, script_path);
     if( ! run_command(cmd) )
     {
-	info = g_strdup_printf(_("Error running openssl script 2:\n%s\n"), script_path);
-	show_info(info);
-	g_free(info);
-	g_free(script_path);
-	g_free(cmd);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error running openssl script 2:\n%s\n"), script_path);
+        show_info(info);
+        g_free(info);
+        g_free(script_path);
+        g_free(cmd);
+        g_free(cert_dir);
+        return;
     }
     g_free(cmd);
 
     /* Create the third openssl script */
     if((fp=fopen(script_path, "w+"))==NULL)
     {
-	info = g_strdup_printf(_("Error writing gadmin-openvpn-openssl.conf here: \n%s\n"), script_path);
-	show_info(info);
-	g_free(info);
-	g_free(script_path);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error writing gadmin-openvpn-openssl.conf here: \n%s\n"), script_path);
+        show_info(info);
+        g_free(info);
+        g_free(script_path);
+        g_free(cert_dir);
+        return;
     }
     openssl_script = g_strconcat("",
-    "#!/bin/bash\n\n",
+        "#!/bin/bash\n\n",
 
-    "openssl ca -out cert.pem -config ",  openssl_config_path, " -batch  -passin file:", passfile, " -infiles req.pem\n\n",
+        "openssl ca -out cert.pem -config ",  openssl_config_path, " -batch  -passin file:", passfile, " -infiles req.pem\n\n",
 
-    "rm -f index*\n",
-    "rm -f serial*\n",
-    NULL);
+        "rm -f index*\n",
+        "rm -f serial*\n",
+        NULL);
     fputs(openssl_script, fp);
     fclose(fp);
     g_free(openssl_script);
@@ -402,20 +387,20 @@ void generate_cert(struct w *widgets)
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), _("Signing client certificate"));
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), val);
     while(gtk_events_pending())
-	  gtk_main_iteration();
+        gtk_main_iteration();
     sleep(1);
 
     /* Run the third openssl script */
     cmd = g_strdup_printf("chmod 755 %s && %s", script_path, script_path);
     if( ! run_command(cmd) )
     {
-	info = g_strdup_printf(_("Error running openssl script 3:\n%s\n"), script_path);
-	show_info(info);
-	g_free(info);
-	g_free(script_path);
-	g_free(cmd);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error running openssl script 3:\n%s\n"), script_path);
+        show_info(info);
+        g_free(info);
+        g_free(script_path);
+        g_free(cmd);
+        g_free(cert_dir);
+        return;
     }
     g_free(cmd);
 
@@ -424,31 +409,28 @@ void generate_cert(struct w *widgets)
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), "Certificate creation successful");
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), val);
     while(gtk_events_pending())
-	gtk_main_iteration();
-
+        gtk_main_iteration();
 
     sleep(3);
 
-
     /* Reset progress indicator */
     val=0.0;
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), "Generating DH parameters");
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), val);
     while(gtk_events_pending())
-	gtk_main_iteration();
-
+        gtk_main_iteration();
 
     /* Generate Diffie Hellman parameters: openssl dhparam -out dh.pem 1024 */
     cmd = g_strdup_printf("openssl dhparam -out %s/dh.pem %s", cert_dir, bits);
     if( ! run_command(cmd) )
     {
-	info = g_strdup_printf(_("Error generating Diffie Hellman parameters.\n"));
-	show_info(info);
-	g_free(info);
-	g_free(script_path);
-	g_free(cmd);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error generating Diffie Hellman parameters.\n"));
+        show_info(info);
+        g_free(info);
+        g_free(script_path);
+        g_free(cmd);
+        g_free(cert_dir);
+        return;
     }
     g_free(cmd);
 
@@ -459,20 +441,20 @@ void generate_cert(struct w *widgets)
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), "Generating HMAC Firewall");
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), val);
     while(gtk_events_pending())
-	gtk_main_iteration();
+        gtk_main_iteration();
 
 
     /* Generate ta.key HMAC Firewall: openvpn --genkey --secret ta.key */
     cmd = g_strdup_printf("%s --genkey --secret %s/ta.key", OPENVPN_BINARY, cert_dir);
     if( ! run_command(cmd) )
     {
-	info = g_strdup_printf(_("Error generating HMAC Firweall key.\n"));
-	show_info(info);
-	g_free(info);
-	g_free(script_path);
-	g_free(cmd);
-	g_free(cert_dir);
-	return;
+        info = g_strdup_printf(_("Error generating HMAC Firweall key.\n"));
+        show_info(info);
+        g_free(info);
+        g_free(script_path);
+        g_free(cmd);
+        g_free(cert_dir);
+        return;
     }
     g_free(cmd);
 
@@ -480,7 +462,7 @@ void generate_cert(struct w *widgets)
     gtk_progress_bar_set_text(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), "Certificate creation successful");
     gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(widgets->gen_cert_progressbar), val);
     while(gtk_events_pending())
-	gtk_main_iteration();
+        gtk_main_iteration();
 
 
     /* Remove the script and passfile */
@@ -493,10 +475,10 @@ void generate_cert(struct w *widgets)
 
 
     info = g_strconcat(
-    "\n",
-    _("The keys and certificates have been created successfully.\n"),
-    _("They will be used by new OpenVPN logins after a server restart.\n"),
-    "\n", NULL);
+            "\n",
+            _("The keys and certificates have been created successfully.\n"),
+            _("They will be used by new OpenVPN logins after a server restart.\n"),
+            "\n", NULL);
     show_info(info);
     g_free(info);
 
@@ -504,63 +486,51 @@ void generate_cert(struct w *widgets)
     reread_conf(widgets);
 
 
-    /* Copy server certificates to the client certificate directory */
+    /* Copy cacert.pem to the client certificate directory */
     cmd = g_strdup_printf("cp %s/server/certs/cacert.pem %s/server/client/certs/", OPENVPN_SYSCONF_DIR, OPENVPN_SYSCONF_DIR);
     if( ! run_command(cmd) )
     {
-	info = g_strdup_printf(_("Error: Could not copy certificates to the client directory.\n"));
-	show_info(info);
-	g_free(info);
-	g_free(cmd);
-	return;
+        info = g_strdup_printf(_("Error: Could not copy certificates to the client directory.\n"));
+        show_info(info);
+        g_free(info);
+        g_free(cmd);
+        return;
     }
     g_free(cmd);
 
-    /* Copy server certificates to the client certificate directory */
+    /* Copy cert.pem to the client certificate directory */
     cmd = g_strdup_printf("cp %s/server/certs/cert.pem %s/server/client/certs/", OPENVPN_SYSCONF_DIR, OPENVPN_SYSCONF_DIR);
     if( ! run_command(cmd) )
     {
-	info = g_strdup_printf(_("Error: Could not copy certificates to the client directory.\n"));
-	show_info(info);
-	g_free(info);
-	g_free(cmd);
-	return;
+        info = g_strdup_printf(_("Error: Could not copy certificates to the client directory.\n"));
+        show_info(info);
+        g_free(info);
+        g_free(cmd);
+        return;
     }
     g_free(cmd);
 
-    /* Copy server certificates to the client certificate directory */
-    cmd = g_strdup_printf("cp %s/server/certs/dh.pem %s/server/client/certs/", OPENVPN_SYSCONF_DIR, OPENVPN_SYSCONF_DIR);
-    if( ! run_command(cmd) )
-    {
-	info = g_strdup_printf(_("Error: Could not copy certificates to the client directory.\n"));
-	show_info(info);
-	g_free(info);
-	g_free(cmd);
-	return;
-    }
-    g_free(cmd);
-
-    /* Copy server certificates to the client certificate directory */
+    /* Copy key.pem to the client certificate directory */
     cmd = g_strdup_printf("cp %s/server/certs/key.pem %s/server/client/certs/", OPENVPN_SYSCONF_DIR, OPENVPN_SYSCONF_DIR);
     if( ! run_command(cmd) )
     {
-	info = g_strdup_printf(_("Error: Could not copy certificates to the client directory.\n"));
-	show_info(info);
-	g_free(info);
-	g_free(cmd);
-	return;
+        info = g_strdup_printf(_("Error: Could not copy certificates to the client directory.\n"));
+        show_info(info);
+        g_free(info);
+        g_free(cmd);
+        return;
     }
     g_free(cmd);
 
-    /* Copy server certificates to the client certificate directory */
+    /* Copy ta.key to the client certificate directory */
     cmd = g_strdup_printf("cp %s/server/certs/ta.key %s/server/client/certs/", OPENVPN_SYSCONF_DIR, OPENVPN_SYSCONF_DIR);
     if( ! run_command(cmd) )
     {
-	info = g_strdup_printf(_("Error: Could not copy certificates to the client directory.\n"));
-	show_info(info);
-	g_free(info);
-	g_free(cmd);
-	return;
+        info = g_strdup_printf(_("Error: Could not copy certificates to the client directory.\n"));
+        show_info(info);
+        g_free(info);
+        g_free(cmd);
+        return;
     }
     g_free(cmd);
 }
